@@ -1,5 +1,8 @@
 from rest_framework import serializers
-from kfsd.apps.endpoints.serializers.base import BaseInputReqSerializer, BaseOutputRespSerializer
+from kfsd.apps.endpoints.serializers.base import (
+    BaseInputReqSerializer,
+    BaseOutputRespSerializer,
+)
 
 
 class ArrUtilsInputReqSerializer(BaseInputReqSerializer):
